package com.perforce.hwsclient;

import retrofit.Callback;
import retrofit.http.*;

import com.perforce.hwsclient.models.LoginResponse;
import com.perforce.hwsclient.models.P4dConfigId;
import com.perforce.hwsclient.models.HWSStatus;
import com.perforce.hwsclient.models.BranchesCommand;
import com.perforce.hwsclient.models.BranchCommand;
import com.perforce.hwsclient.models.CommandResponse;
import com.perforce.hwsclient.models.ChangesCommand;
import com.perforce.hwsclient.models.ChangeCommand;
import com.perforce.hwsclient.models.ClientsCommand;
import com.perforce.hwsclient.models.ClientCommand;
import com.perforce.hwsclient.models.CommandRequest;
import com.perforce.hwsclient.models.Counter;
import com.perforce.hwsclient.models.DepotsCommand;
import com.perforce.hwsclient.models.DepotCommand;
import com.perforce.hwsclient.models.GroupsCommand;
import com.perforce.hwsclient.models.GroupCommand;
import com.perforce.hwsclient.models.JobsCommand;
import com.perforce.hwsclient.models.JobCommand;
import com.perforce.hwsclient.models.LabelsCommand;
import com.perforce.hwsclient.models.LabelCommand;
import com.perforce.hwsclient.models.Location;
import com.perforce.hwsclient.models.Protections;
import com.perforce.hwsclient.models.ServersCommand;
import com.perforce.hwsclient.models.ServerCommand;
import com.perforce.hwsclient.models.StreamsCommand;
import com.perforce.hwsclient.models.StreamCommand;
import com.perforce.hwsclient.models.Triggers;
import com.perforce.hwsclient.models.UsersCommand;
import com.perforce.hwsclient.models.UserCommand;

    import java.util.ArrayList;
    import java.util.HashMap;
    import java.util.List;
    import java.util.Map;

    public interface DefaultApi {
    
        /**
        * 
        * Sync method
        * Logs into Helix Web Services.\n\nThis can either be a p4d instance or Helix Cloud, depending upon the\nconfiguration of your Helix Web Services instance.
           * @return LoginResponse}
        */
        
        @POST("/hws/v16.1/login")
        LoginResponse login();
        

        /**
        * 
        * Async method
           * @param cb callback method
        */
        
        @POST("/hws/v16.1/login")
        void login(
        Callback<LoginResponse> cb
            );
    
        /**
        * 
        * Sync method
        * The list of registered p4d servers in your cluster.\n\nThis is provided by a special set of configuration files in the system.\nFor more information, consult the Helix Web Services user guide.
           * @return List&lt;P4dConfigId&gt;}
        */
        
        @GET("/hws/v16.1/servers")
        List<P4dConfigId> getP4dServers();
        

        /**
        * 
        * Async method
           * @param cb callback method
        */
        
        @GET("/hws/v16.1/servers")
        void getP4dServers(
        Callback<List<P4dConfigId>> cb
            );
    
        /**
        * 
        * Sync method
        * A simple structure to monitor for \&quot;problems\&quot; an admin should take care of, and, report the current application version.\n\nThis method does not require authentication.
           * @return HWSStatus}
        */
        
        @GET("/hws/v16.1/status")
        HWSStatus getStatus();
        

        /**
        * 
        * Async method
           * @param cb callback method
        */
        
        @GET("/hws/v16.1/status")
        void getStatus(
        Callback<HWSStatus> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available branches in the system.\nThe resources of this list are summaries of branches in the system.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;BranchesCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/branches")
        List<BranchesCommand> getBranches(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/branches")
        void getBranches(
        @Path("server") String server, Callback<List<BranchesCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Creates a new branch specification, like the `p4 branch` command.
           * @param server The server ID that we execute this particular method against.
           * @param body The branch specification.
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/branches")
        CommandResponse addBranch(
        @Path("server") String server, @Body BranchCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param body The branch specification.
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/branches")
        void addBranch(
        @Path("server") String server, @Body BranchCommand body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the branch spec details of the particular branch.
           * @param server The server ID that we execute this particular method against.
           * @param branch The branch ID
           * @return BranchCommand}
        */
        
        @GET("/p4d/v16.1/{server}/branches/{branch}")
        BranchCommand getBranch(
        @Path("server") String server, @Path("branch") String branch
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param branch The branch ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/branches/{branch}")
        void getBranch(
        @Path("server") String server, @Path("branch") String branch, Callback<BranchCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the branch specification, similar to the `p4 branch -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param branch The branch ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/branches/{branch}")
        CommandResponse deleteBranch(
        @Path("server") String server, @Path("branch") String branch
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param branch The branch ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/branches/{branch}")
        void deleteBranch(
        @Path("server") String server, @Path("branch") String branch, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Update branch specifications, similar to the `p4 branch` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param branch The branch ID
           * @param body Fields of the branch to update
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/branches/{branch}")
        CommandResponse updateBranch(
        @Path("server") String server, @Path("branch") String branch, @Body BranchCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param branch The branch ID
           * @param body Fields of the branch to update
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/branches/{branch}")
        void updateBranch(
        @Path("server") String server, @Path("branch") String branch, @Body BranchCommand body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available changes in the system.\nThe resources of this list are summaries of changes in the system.
           * @param server The server ID that we execute this particular method against.
           * @param max Limit the number of change results
           * @param status The status of the changes, e.g., `submitted`
           * @param user The user&#39;s login who submitted the change
           * @param files Limit changes to the depot path expressions. See the link:http://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_changes.html[changes] command description.
           * @return List&lt;ChangesCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/changes")
        List<ChangesCommand> getChanges(
        @Path("server") String server, @Query("max") Integer max, @Query("status") String status, @Query("user") String user, @Query("files") String files
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param max Limit the number of change results
           * @param status The status of the changes, e.g., `submitted`
           * @param user The user&#39;s login who submitted the change
           * @param files Limit changes to the depot path expressions. See the link:http://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_changes.html[changes] command description.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/changes")
        void getChanges(
        @Path("server") String server, @Query("max") Integer max, @Query("status") String status, @Query("user") String user, @Query("files") String files, Callback<List<ChangesCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the change spec details of the particular change.
           * @param server The server ID that we execute this particular method against.
           * @param change The change ID
           * @return ChangeCommand}
        */
        
        @GET("/p4d/v16.1/{server}/changes/{change}")
        ChangeCommand getChange(
        @Path("server") String server, @Path("change") String change
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param change The change ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/changes/{change}")
        void getChange(
        @Path("server") String server, @Path("change") String change, Callback<ChangeCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available clients in the system.\nThe resources of this list are summaries of clients in the system.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;ClientsCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/clients")
        List<ClientsCommand> getClients(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/clients")
        void getClients(
        @Path("server") String server, Callback<List<ClientsCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Creates a new client specification, like the `p4 client` command.
           * @param server The server ID that we execute this particular method against.
           * @param client The client spec
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/clients")
        CommandResponse addClient(
        @Path("server") String server, @Body ClientCommand client
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param client The client spec
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/clients")
        void addClient(
        @Path("server") String server, @Body ClientCommand client, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the client spec details of the particular client.
           * @param server The server ID that we execute this particular method against.
           * @param client The client ID
           * @return ClientCommand}
        */
        
        @GET("/p4d/v16.1/{server}/clients/{client}")
        ClientCommand getClient(
        @Path("server") String server, @Path("client") String client
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param client The client ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/clients/{client}")
        void getClient(
        @Path("server") String server, @Path("client") String client, Callback<ClientCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the client specification, similar to the `p4 client -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param client The client ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/clients/{client}")
        CommandResponse deleteClient(
        @Path("server") String server, @Path("client") String client
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param client The client ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/clients/{client}")
        void deleteClient(
        @Path("server") String server, @Path("client") String client, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Update client specifications, similar to the `p4 client` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param client The client ID
           * @param body Fields of the client to update
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/clients/{client}")
        CommandResponse updateClient(
        @Path("server") String server, @Path("client") String client, @Body ClientCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param client The client ID
           * @param body Fields of the client to update
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/clients/{client}")
        void updateClient(
        @Path("server") String server, @Path("client") String client, @Body ClientCommand body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Execute a Perforce command that requires no input.\nThis only allows commands that have been whitelisted on your system.\nSee the &lt;&lt;system_configuration&gt;&gt; section for details.
           * @param server The server ID that we execute this particular method against.
           * @param command The command name
           * @param arg Command arguments
           * @return CommandResponse}
        */
        
        @GET("/p4d/v16.1/{server}/commands/{command}")
        CommandResponse runCommand(
        @Path("server") String server, @Path("command") String command, @Query("arg") List<String> arg
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param command The command name
           * @param arg Command arguments
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/commands/{command}")
        void runCommand(
        @Path("server") String server, @Path("command") String command, @Query("arg") List<String> arg, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Execute a Perforce command that accepts input, like a spec.\nThis only allows commands that have been whitelisted on your system.\nSee the &lt;&lt;system_configuration&gt;&gt; section for details.
           * @param server The server ID that we execute this particular method against.
           * @param command The command name
           * @param arg Command arguments
           * @param input A hash used as input to the command
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/commands/{command}")
        CommandResponse runCommandWithInput(
        @Path("server") String server, @Path("command") String command, @Query("arg") List<String> arg, @Body CommandRequest input
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param command The command name
           * @param arg Command arguments
           * @param input A hash used as input to the command
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/commands/{command}")
        void runCommandWithInput(
        @Path("server") String server, @Path("command") String command, @Query("arg") List<String> arg, @Body CommandRequest input, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available counters in the system.\nThe resources of this list are summaries of counters in the system.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;Counter&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/counters")
        List<Counter> getCounters(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/counters")
        void getCounters(
        @Path("server") String server, Callback<List<Counter>> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the counter spec details of the particular counter.
           * @param server The server ID that we execute this particular method against.
           * @param counter The counter ID
           * @return Counter}
        */
        
        @GET("/p4d/v16.1/{server}/counters/{counter}")
        Counter getCounter(
        @Path("server") String server, @Path("counter") String counter
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param counter The counter ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/counters/{counter}")
        void getCounter(
        @Path("server") String server, @Path("counter") String counter, Callback<Counter> cb
            );
    
        /**
        * 
        * Sync method
        * Update counter specifications, similar to the `p4 counter` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param counter The counter ID
           * @param body Fields of the counter to update
           * @return CommandResponse}
        */
        
        @PUT("/p4d/v16.1/{server}/counters/{counter}")
        CommandResponse setCounter(
        @Path("server") String server, @Path("counter") String counter, @Body Counter body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param counter The counter ID
           * @param body Fields of the counter to update
           * @param cb callback method
        */
        
        @PUT("/p4d/v16.1/{server}/counters/{counter}")
        void setCounter(
        @Path("server") String server, @Path("counter") String counter, @Body Counter body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the counter specification, similar to the `p4 counter -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param counter The counter ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/counters/{counter}")
        CommandResponse deleteCounter(
        @Path("server") String server, @Path("counter") String counter
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param counter The counter ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/counters/{counter}")
        void deleteCounter(
        @Path("server") String server, @Path("counter") String counter, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Increments a numerical counter, similar to the `p4 counter -i` command.
           * @param server The server ID that we execute this particular method against.
           * @param counter The counter ID
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/counters/{counter}/increment")
        CommandResponse incrementCounter(
        @Path("server") String server, @Path("counter") String counter
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param counter The counter ID
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/counters/{counter}/increment")
        void incrementCounter(
        @Path("server") String server, @Path("counter") String counter, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available depots in the system.\nThe resources of this list are summaries of depots in the system.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;DepotsCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/depots")
        List<DepotsCommand> getDepots(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/depots")
        void getDepots(
        @Path("server") String server, Callback<List<DepotsCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Creates a new depot specification, like the `p4 depot` command.
           * @param server The server ID that we execute this particular method against.
           * @param depot The depot spec
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/depots")
        CommandResponse addDepot(
        @Path("server") String server, @Body DepotCommand depot
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param depot The depot spec
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/depots")
        void addDepot(
        @Path("server") String server, @Body DepotCommand depot, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the depot spec details of the particular depot.
           * @param server The server ID that we execute this particular method against.
           * @param depot The depot ID
           * @return DepotCommand}
        */
        
        @GET("/p4d/v16.1/{server}/depots/{depot}")
        DepotCommand getDepot(
        @Path("server") String server, @Path("depot") String depot
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param depot The depot ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/depots/{depot}")
        void getDepot(
        @Path("server") String server, @Path("depot") String depot, Callback<DepotCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the depot specification, similar to the `p4 depot -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param depot The depot ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/depots/{depot}")
        CommandResponse deleteDepot(
        @Path("server") String server, @Path("depot") String depot
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param depot The depot ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/depots/{depot}")
        void deleteDepot(
        @Path("server") String server, @Path("depot") String depot, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Update depot specifications, similar to the `p4 depot` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param depot The depot ID
           * @param body Fields of the depot to update
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/depots/{depot}")
        CommandResponse updateDepot(
        @Path("server") String server, @Path("depot") String depot, @Body DepotCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param depot The depot ID
           * @param body Fields of the depot to update
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/depots/{depot}")
        void updateDepot(
        @Path("server") String server, @Path("depot") String depot, @Body DepotCommand body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available groups in the system.\nThe resources of this list are summaries of groups in the system.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;GroupsCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/groups")
        List<GroupsCommand> getGroups(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/groups")
        void getGroups(
        @Path("server") String server, Callback<List<GroupsCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Creates a new group specification, like the `p4 group` command.
           * @param server The server ID that we execute this particular method against.
           * @param body The group spec
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/groups")
        CommandResponse addGroup(
        @Path("server") String server, @Body GroupCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param body The group spec
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/groups")
        void addGroup(
        @Path("server") String server, @Body GroupCommand body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the group spec details of the particular group.
           * @param server The server ID that we execute this particular method against.
           * @param group The group ID
           * @return GroupCommand}
        */
        
        @GET("/p4d/v16.1/{server}/groups/{group}")
        GroupCommand getGroup(
        @Path("server") String server, @Path("group") String group
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param group The group ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/groups/{group}")
        void getGroup(
        @Path("server") String server, @Path("group") String group, Callback<GroupCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the group specification, similar to the `p4 group -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param group The group ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/groups/{group}")
        CommandResponse deleteGroup(
        @Path("server") String server, @Path("group") String group
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param group The group ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/groups/{group}")
        void deleteGroup(
        @Path("server") String server, @Path("group") String group, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Update group specifications, similar to the `p4 group` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param group The group ID
           * @param body Fields of the group to update
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/groups/{group}")
        CommandResponse updateGroup(
        @Path("server") String server, @Path("group") String group, @Body GroupCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param group The group ID
           * @param body Fields of the group to update
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/groups/{group}")
        void updateGroup(
        @Path("server") String server, @Path("group") String group, @Body GroupCommand body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available jobs in the system.\nThe resources of this list are summaries of jobs in the system.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;JobsCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/jobs")
        List<JobsCommand> getJobs(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/jobs")
        void getJobs(
        @Path("server") String server, Callback<List<JobsCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Creates a new job specification, like the `p4 job` command.
           * @param server The server ID that we execute this particular method against.
           * @param job The job spec
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/jobs")
        CommandResponse addJob(
        @Path("server") String server, @Body JobCommand job
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param job The job spec
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/jobs")
        void addJob(
        @Path("server") String server, @Body JobCommand job, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the job spec details of the particular job.
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @return JobCommand}
        */
        
        @GET("/p4d/v16.1/{server}/jobs/{job}")
        JobCommand getJob(
        @Path("server") String server, @Path("job") String job
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/jobs/{job}")
        void getJob(
        @Path("server") String server, @Path("job") String job, Callback<JobCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the job specification, similar to the `p4 job -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/jobs/{job}")
        CommandResponse deleteJob(
        @Path("server") String server, @Path("job") String job
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/jobs/{job}")
        void deleteJob(
        @Path("server") String server, @Path("job") String job, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Update job specifications, similar to the `p4 job` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @param jobCommand Fields of the job to update
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/jobs/{job}")
        CommandResponse updateJob(
        @Path("server") String server, @Path("job") String job, @Body JobCommand jobCommand
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @param jobCommand Fields of the job to update
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/jobs/{job}")
        void updateJob(
        @Path("server") String server, @Path("job") String job, @Body JobCommand jobCommand, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Adds a fix record to the job for a particular changelist.
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @param change The change ID
           * @param status Specify the job status instead of using the default.\nThe default is typically `closed` or some other value defined in the `Presets` field specified in the `p4 jobspec` form.\n\nIf the changelist to which you&#39;re linking the job been submitted, the status value is immediately reflected in the job&#39;s status.\n\nIf the changelist is pending, the job status is changed on submission of the changelist, provided that the -s option is also supplied to p4 submit and the desired status appears next to the job in the p4 submit form&#39;s Jobs: field.\nTo leave a job unchanged, use the special status of same.
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/jobs/{job}/fixes/{change}")
        CommandResponse addJobFix(
        @Path("server") String server, @Path("job") String job, @Path("change") String change, @Query("status") String status
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @param change The change ID
           * @param status Specify the job status instead of using the default.\nThe default is typically `closed` or some other value defined in the `Presets` field specified in the `p4 jobspec` form.\n\nIf the changelist to which you&#39;re linking the job been submitted, the status value is immediately reflected in the job&#39;s status.\n\nIf the changelist is pending, the job status is changed on submission of the changelist, provided that the -s option is also supplied to p4 submit and the desired status appears next to the job in the p4 submit form&#39;s Jobs: field.\nTo leave a job unchanged, use the special status of same.
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/jobs/{job}/fixes/{change}")
        void addJobFix(
        @Path("server") String server, @Path("job") String job, @Path("change") String change, @Query("status") String status, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the fix record association for the job for a particular changelist.
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @param change The change ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/jobs/{job}/fixes/{change}")
        CommandResponse deleteJobFix(
        @Path("server") String server, @Path("job") String job, @Path("change") String change
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param job The job ID
           * @param change The change ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/jobs/{job}/fixes/{change}")
        void deleteJobFix(
        @Path("server") String server, @Path("job") String job, @Path("change") String change, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available labels in the system.\nThe resources of this list are summaries of labels in the system.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;LabelsCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/labels")
        List<LabelsCommand> getLabels(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/labels")
        void getLabels(
        @Path("server") String server, Callback<List<LabelsCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Creates a new label specification, like the `p4 label` command.
           * @param server The server ID that we execute this particular method against.
           * @param label The label spec
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/labels")
        CommandResponse addLabel(
        @Path("server") String server, @Body LabelCommand label
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param label The label spec
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/labels")
        void addLabel(
        @Path("server") String server, @Body LabelCommand label, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the label spec details of the particular label.
           * @param server The server ID that we execute this particular method against.
           * @param label The label ID
           * @return LabelCommand}
        */
        
        @GET("/p4d/v16.1/{server}/labels/{label}")
        LabelCommand getLabel(
        @Path("server") String server, @Path("label") String label
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param label The label ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/labels/{label}")
        void getLabel(
        @Path("server") String server, @Path("label") String label, Callback<LabelCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the label specification, similar to the `p4 label -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param label The label ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/labels/{label}")
        CommandResponse deleteLabel(
        @Path("server") String server, @Path("label") String label
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param label The label ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/labels/{label}")
        void deleteLabel(
        @Path("server") String server, @Path("label") String label, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Update label specifications, similar to the `p4 label` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param label The label ID
           * @param labelCommand Fields of the label to update
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/labels/{label}")
        CommandResponse updateLabel(
        @Path("server") String server, @Path("label") String label, @Body LabelCommand labelCommand
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param label The label ID
           * @param labelCommand Fields of the label to update
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/labels/{label}")
        void updateLabel(
        @Path("server") String server, @Path("label") String label, @Body LabelCommand labelCommand, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Logs into a Helix Versioning Engine (p4d) server.
           * @param server The server ID that we execute this particular method against.
           * @return LoginResponse}
        */
        
        @POST("/p4d/v16.1/{server}/login")
        LoginResponse serverLogin(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/login")
        void serverLogin(
        @Path("server") String server, Callback<LoginResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists depots, files, and directories in the system.\nThis combines the output of the `p4 depots`, `p4 dirs`, and `p4 files` commands, depending upon your path.
           * @param server The server ID that we execute this particular method against.
           * @param _path The path \&quot;under a depot\&quot; to query under, e.g., `//depot/main`.\nThis will list the directories and files underneath that path.
           * @return List&lt;Location&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/paths")
        List<Location> getPaths(
        @Path("server") String server, @Query("path") String _path
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param _path The path \&quot;under a depot\&quot; to query under, e.g., `//depot/main`.\nThis will list the directories and files underneath that path.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/paths")
        void getPaths(
        @Path("server") String server, @Query("path") String _path, Callback<List<Location>> cb
            );
    
        /**
        * 
        * Sync method
        * Returns a list of available protections in the system.\nThe elements of this list are rows of the system&#39;s protections table.\n\nThis method requires superuser access.\n\nSee the output of http://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_protect.html[`p4 protect`] for more information.
           * @param server The server ID that we execute this particular method against.
           * @return Protections}
        */
        
        @GET("/p4d/v16.1/{server}/protections")
        Protections getProtections(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/protections")
        void getProtections(
        @Path("server") String server, Callback<Protections> cb
            );
    
        /**
        * 
        * Sync method
        * Updates the protections table.\n\nThis method requires superuser access.
           * @param server The server ID that we execute this particular method against.
           * @param protections The new protections table
           * @return CommandResponse}
        */
        
        @PUT("/p4d/v16.1/{server}/protections")
        CommandResponse updateProtections(
        @Path("server") String server, @Body Protections protections
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param protections The new protections table
           * @param cb callback method
        */
        
        @PUT("/p4d/v16.1/{server}/protections")
        void updateProtections(
        @Path("server") String server, @Body Protections protections, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available servers in the system.\nThe resources of this list are summaries of servers in the system.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;ServersCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/servers")
        List<ServersCommand> getServers(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/servers")
        void getServers(
        @Path("server") String server, Callback<List<ServersCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Creates a new server specification, like the `p4 server` command.
           * @param server The server ID that we execute this particular method against.
           * @param serverCommand The server spec
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/servers")
        CommandResponse addServer(
        @Path("server") String server, @Body ServerCommand serverCommand
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param serverCommand The server spec
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/servers")
        void addServer(
        @Path("server") String server, @Body ServerCommand serverCommand, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the server spec details of the particular server.
           * @param server The server ID that we execute this particular method against.
           * @param serverId The server ID of the server spec
           * @return ServerCommand}
        */
        
        @GET("/p4d/v16.1/{server}/servers/{serverId}")
        ServerCommand getServer(
        @Path("server") String server, @Path("serverId") String serverId
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param serverId The server ID of the server spec
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/servers/{serverId}")
        void getServer(
        @Path("server") String server, @Path("serverId") String serverId, Callback<ServerCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the server specification, similar to the `p4 server -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param serverId The server ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/servers/{serverId}")
        CommandResponse deleteServer(
        @Path("server") String server, @Path("serverId") String serverId
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param serverId The server ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/servers/{serverId}")
        void deleteServer(
        @Path("server") String server, @Path("serverId") String serverId, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Update server specifications, similar to the `p4 server` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param serverId The server ID
           * @param serverCommand Fields of the server to update
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/servers/{serverId}")
        CommandResponse updateServer(
        @Path("server") String server, @Path("serverId") String serverId, @Body ServerCommand serverCommand
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param serverId The server ID
           * @param serverCommand Fields of the server to update
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/servers/{serverId}")
        void updateServer(
        @Path("server") String server, @Path("serverId") String serverId, @Body ServerCommand serverCommand, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available streams in the system.\nThe resources of this list are summaries of streams in the system.
           * @param server The server ID that we execute this particular method against.
           * @return List&lt;StreamsCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/streams")
        List<StreamsCommand> getStreams(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/streams")
        void getStreams(
        @Path("server") String server, Callback<List<StreamsCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Creates a new stream specification, like the `p4 stream` command.
           * @param server The server ID that we execute this particular method against.
           * @param body The stream spec
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/streams")
        CommandResponse addStream(
        @Path("server") String server, @Body StreamCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param body The stream spec
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/streams")
        void addStream(
        @Path("server") String server, @Body StreamCommand body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the stream spec details of the particular stream.
           * @param server The server ID that we execute this particular method against.
           * @param stream The stream ID
           * @return StreamCommand}
        */
        
        @GET("/p4d/v16.1/{server}/streams/stream")
        StreamCommand getStream(
        @Path("server") String server, @Query("stream") String stream
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param stream The stream ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/streams/stream")
        void getStream(
        @Path("server") String server, @Query("stream") String stream, Callback<StreamCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the stream specification, similar to the `p4 stream -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param stream The stream ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/streams/stream")
        CommandResponse deleteStream(
        @Path("server") String server, @Query("stream") String stream
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param stream The stream ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/streams/stream")
        void deleteStream(
        @Path("server") String server, @Query("stream") String stream, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Update stream specifications, similar to the `p4 stream` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param stream The stream ID
           * @param body Fields of the stream to update
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/streams/stream")
        CommandResponse updateStream(
        @Path("server") String server, @Query("stream") String stream, @Body StreamCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param stream The stream ID
           * @param body Fields of the stream to update
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/streams/stream")
        void updateStream(
        @Path("server") String server, @Query("stream") String stream, @Body StreamCommand body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns a list of available triggers in the system.\nThe elements of this list are rows of the system&#39;s triggers table.\n\nThis method requires superuser access.
           * @param server The server ID that we execute this particular method against.
           * @return Triggers}
        */
        
        @GET("/p4d/v16.1/{server}/triggers")
        Triggers getTriggers(
        @Path("server") String server
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/triggers")
        void getTriggers(
        @Path("server") String server, Callback<Triggers> cb
            );
    
        /**
        * 
        * Sync method
        * Updates the triggers table.\n\nThis method requires superuser access.
           * @param server The server ID that we execute this particular method against.
           * @param triggers The new triggers table
           * @return CommandResponse}
        */
        
        @PUT("/p4d/v16.1/{server}/triggers")
        CommandResponse updateTriggers(
        @Path("server") String server, @Body Triggers triggers
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param triggers The new triggers table
           * @param cb callback method
        */
        
        @PUT("/p4d/v16.1/{server}/triggers")
        void updateTriggers(
        @Path("server") String server, @Body Triggers triggers, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Lists available users in the system.\nThe resources of this list are summaries of users in the system.
           * @param server The server ID that we execute this particular method against.
           * @param includeService If true, shows service users in the list.
           * @param max Cap the number of users reported to this amount.
           * @return List&lt;UsersCommand&gt;}
        */
        
        @GET("/p4d/v16.1/{server}/users")
        List<UsersCommand> getUsers(
        @Path("server") String server, @Query("includeService") Boolean includeService, @Query("max") Integer max
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param includeService If true, shows service users in the list.
           * @param max Cap the number of users reported to this amount.
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/users")
        void getUsers(
        @Path("server") String server, @Query("includeService") Boolean includeService, @Query("max") Integer max, Callback<List<UsersCommand>> cb
            );
    
        /**
        * 
        * Sync method
        * Creates a new user specification, like the `p4 user` command.
           * @param server The server ID that we execute this particular method against.
           * @param body The user spec
           * @return CommandResponse}
        */
        
        @POST("/p4d/v16.1/{server}/users")
        CommandResponse addUser(
        @Path("server") String server, @Body UserCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param body The user spec
           * @param cb callback method
        */
        
        @POST("/p4d/v16.1/{server}/users")
        void addUser(
        @Path("server") String server, @Body UserCommand body, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Returns the user spec details of the particular user.
           * @param server The server ID that we execute this particular method against.
           * @param user The user ID
           * @return UserCommand}
        */
        
        @GET("/p4d/v16.1/{server}/users/{user}")
        UserCommand getUser(
        @Path("server") String server, @Path("user") String user
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param user The user ID
           * @param cb callback method
        */
        
        @GET("/p4d/v16.1/{server}/users/{user}")
        void getUser(
        @Path("server") String server, @Path("user") String user, Callback<UserCommand> cb
            );
    
        /**
        * 
        * Sync method
        * Removes the user specification, similar to the `p4 user -d` command.
           * @param server The server ID that we execute this particular method against.
           * @param user The user ID
           * @return CommandResponse}
        */
        
        @DELETE("/p4d/v16.1/{server}/users/{user}")
        CommandResponse deleteUser(
        @Path("server") String server, @Path("user") String user
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param user The user ID
           * @param cb callback method
        */
        
        @DELETE("/p4d/v16.1/{server}/users/{user}")
        void deleteUser(
        @Path("server") String server, @Path("user") String user, Callback<CommandResponse> cb
            );
    
        /**
        * 
        * Sync method
        * Update user specifications, similar to the `p4 user` command.\nOnly the specified parameters in the body will be changed.
           * @param server The server ID that we execute this particular method against.
           * @param user The user ID
           * @param body Fields of the user to update
           * @return CommandResponse}
        */
        
        @PATCH("/p4d/v16.1/{server}/users/{user}")
        CommandResponse updateUser(
        @Path("server") String server, @Path("user") String user, @Body UserCommand body
            );

        /**
        * 
        * Async method
           * @param server The server ID that we execute this particular method against.
           * @param user The user ID
           * @param body Fields of the user to update
           * @param cb callback method
        */
        
        @PATCH("/p4d/v16.1/{server}/users/{user}")
        void updateUser(
        @Path("server") String server, @Path("user") String user, @Body UserCommand body, Callback<CommandResponse> cb
            );
    
        }
