package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.Date;

import com.google.gson.annotations.SerializedName;




/**
 * A reference to a branch mapping known to the system.
 **/
@ApiModel(description = "A reference to a branch mapping known to the system.")
public class BranchesCommand   {
  
  @SerializedName("branch")
  private String branch = null;
  
  @SerializedName("owner")
  private String owner = null;
  
  @SerializedName("access")
  private Date access = null;
  
  @SerializedName("update")
  private Date update = null;
  
  @SerializedName("options")
  private String options = null;
  
  @SerializedName("description")
  private String description = null;
  

  
  /**
   * The branch name, as provided on the command line.
   **/
  @ApiModelProperty(value = "The branch name, as provided on the command line.")
  public String getBranch() {
    return branch;
  }
  public void setBranch(String branch) {
    this.branch = branch;
  }

  
  /**
   * The owner of the branch mapping.\nBy default, this will be set to the user who created the branch.\nThis field is unimportant unless the Option: field value is locked.
   **/
  @ApiModelProperty(value = "The owner of the branch mapping.\nBy default, this will be set to the user who created the branch.\nThis field is unimportant unless the Option: field value is locked.")
  public String getOwner() {
    return owner;
  }
  public void setOwner(String owner) {
    this.owner = owner;
  }

  
  /**
   * The date the branch mapping was last accessed.
   **/
  @ApiModelProperty(value = "The date the branch mapping was last accessed.")
  public Date getAccess() {
    return access;
  }
  public void setAccess(Date access) {
    this.access = access;
  }

  
  /**
   * The date the branch mapping was last changed.
   **/
  @ApiModelProperty(value = "The date the branch mapping was last changed.")
  public Date getUpdate() {
    return update;
  }
  public void setUpdate(Date update) {
    this.update = update;
  }

  
  /**
   * Either `unlocked` (the default) or `locked`.\n\nIf `locked`, only the `Owner:` can modify the branch mapping, and the mapping can't be deleted until it is `unlocked`.
   **/
  @ApiModelProperty(value = "Either `unlocked` (the default) or `locked`.\n\nIf `locked`, only the `Owner:` can modify the branch mapping, and the mapping can't be deleted until it is `unlocked`.")
  public String getOptions() {
    return options;
  }
  public void setOptions(String options) {
    this.options = options;
  }

  
  /**
   * A short description of the branch's purpose.
   **/
  @ApiModelProperty(value = "A short description of the branch's purpose.")
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    BranchesCommand branchesCommand = (BranchesCommand) o;
    return Objects.equals(this.branch, branchesCommand.branch) &&
        Objects.equals(this.owner, branchesCommand.owner) &&
        Objects.equals(this.access, branchesCommand.access) &&
        Objects.equals(this.update, branchesCommand.update) &&
        Objects.equals(this.options, branchesCommand.options) &&
        Objects.equals(this.description, branchesCommand.description);
  }

  @Override
  public int hashCode() {
    return Objects.hash(branch, owner, access, update, options, description);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class BranchesCommand {\n");
    
    sb.append("    branch: ").append(toIndentedString(branch)).append("\n");
    sb.append("    owner: ").append(toIndentedString(owner)).append("\n");
    sb.append("    access: ").append(toIndentedString(access)).append("\n");
    sb.append("    update: ").append(toIndentedString(update)).append("\n");
    sb.append("    options: ").append(toIndentedString(options)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
