package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.*;
import java.util.Date;

import com.google.gson.annotations.SerializedName;




/**
 * The Perforce stream specification defines a single stream.\n\nStreams are  hierarchical branches with policies that control the structure and the flow of change.\nStream hierarchies are based on the stability of the streams, specified by the type you assign to the stream.\nDevelopment streams are least stable (most subject to change), mainline streams are somewhat stable, and release streams are highly stable.\nVirtual streams can be used to copy and merge between parent and child streams without storing local data.\nTask streams are lightweight short-lived branches that are useful for bug fixing or new features that only modify a small subset of the branch data.\n\nStream contents are defined by the paths that you map.\nBy default, a stream has the same structure as its parent (the stream from which it was branched), but you can override the structure, for example to ensure that specified files cannot be submitted or integrated to other streams.
 **/
@ApiModel(description = "The Perforce stream specification defines a single stream.\n\nStreams are  hierarchical branches with policies that control the structure and the flow of change.\nStream hierarchies are based on the stability of the streams, specified by the type you assign to the stream.\nDevelopment streams are least stable (most subject to change), mainline streams are somewhat stable, and release streams are highly stable.\nVirtual streams can be used to copy and merge between parent and child streams without storing local data.\nTask streams are lightweight short-lived branches that are useful for bug fixing or new features that only modify a small subset of the branch data.\n\nStream contents are defined by the paths that you map.\nBy default, a stream has the same structure as its parent (the stream from which it was branched), but you can override the structure, for example to ensure that specified files cannot be submitted or integrated to other streams.")
public class StreamCommand   {
  
  @SerializedName("stream")
  private String stream = null;
  
  @SerializedName("update")
  private Date update = null;
  
  @SerializedName("access")
  private Date access = null;
  
  @SerializedName("owner")
  private String owner = null;
  
  @SerializedName("name")
  private String name = null;
  
  @SerializedName("parent")
  private String parent = null;
  
  @SerializedName("type")
  private String type = null;
  
  @SerializedName("description")
  private String description = null;
  
  @SerializedName("options")
  private String options = null;
  
  @SerializedName("paths")
  private List<String> paths = new ArrayList<String>();
  
  @SerializedName("remapped")
  private List<String> remapped = new ArrayList<String>();
  
  @SerializedName("ignored")
  private List<String> ignored = new ArrayList<String>();
  

  
  /**
   * Specifies the stream's name (permanent identifier) and its path in the stream depot, in the form `//depotname/streamname`.
   **/
  @ApiModelProperty(value = "Specifies the stream's name (permanent identifier) and its path in the stream depot, in the form `//depotname/streamname`.")
  public String getStream() {
    return stream;
  }
  public void setStream(String stream) {
    this.stream = stream;
  }

  
  /**
   * The date the stream specification was last modified.
   **/
  @ApiModelProperty(value = "The date the stream specification was last modified.")
  public Date getUpdate() {
    return update;
  }
  public void setUpdate(Date update) {
    this.update = update;
  }

  
  /**
   * The date and time that the stream specification was last accessed by any Perforce command.
   **/
  @ApiModelProperty(value = "The date and time that the stream specification was last accessed by any Perforce command.")
  public Date getAccess() {
    return access;
  }
  public void setAccess(Date access) {
    this.access = access;
  }

  
  /**
   * The Perforce user or group who owns the stream.\nThe default is the user who created the stream.
   **/
  @ApiModelProperty(value = "The Perforce user or group who owns the stream.\nThe default is the user who created the stream.")
  public String getOwner() {
    return owner;
  }
  public void setOwner(String owner) {
    this.owner = owner;
  }

  
  /**
   * Display name of the stream.\nUnlike the Stream: field, this field can be modified.\nDefaults to the streamname portion of the stream path.
   **/
  @ApiModelProperty(value = "Display name of the stream.\nUnlike the Stream: field, this field can be modified.\nDefaults to the streamname portion of the stream path.")
  public String getName() {
    return name;
  }
  public void setName(String name) {
    this.name = name;
  }

  
  /**
   * The parent of this stream.\nMust be none if the stream's `Type:` is mainline, otherwise must be set to an existing stream identifier of the form `//depotname/streamname`.
   **/
  @ApiModelProperty(value = "The parent of this stream.\nMust be none if the stream's `Type:` is mainline, otherwise must be set to an existing stream identifier of the form `//depotname/streamname`.")
  public String getParent() {
    return parent;
  }
  public void setParent(String parent) {
    this.parent = parent;
  }

  
  /**
   * The stream’s type determines the expected flow of change.\nValid stream types are `mainline`, `virtual`, `development`, and `release`.\n\n- `mainline`:\nThe mainline stream is the parent of all streams in the stream depot. Every stream depot must have at least one mainline stream.\n\n- `virtual`:\nVirtual streams allow merging and copying between parent and child streams without storing local data.\nData is passed through to the destination (a non-virtual stream) after applying restrictions on the scope of files defined in the virtual stream’s view.\nBecause virtual streams do not have files in their depot namespace, it is impossible to import a virtual stream.\n\n- `release`:\nMore stable than the mainline.\nRelease streams copy from the parent and merge to the parent.\n\n- `development`:\nLess stable than the mainline.\nDevelopment streams expect to merge from parent streams and copy to the parent.\n\n- `task`:\nTask streams are lightweight short-lived branches that are useful for bug fixing or new features that only modify a small subset of the branch data.\nBecause branched (copied) files are tracked in a set of shadow tables which are later removed, repository metadata is kept to a minimum when using this type of stream.\nWorkspaces associated with task streams see all branched data, but only modified and promoted data is visible to users with access to the stream’s namespace.\nThe default is stream type is development.
   **/
  @ApiModelProperty(value = "The stream’s type determines the expected flow of change.\nValid stream types are `mainline`, `virtual`, `development`, and `release`.\n\n- `mainline`:\nThe mainline stream is the parent of all streams in the stream depot. Every stream depot must have at least one mainline stream.\n\n- `virtual`:\nVirtual streams allow merging and copying between parent and child streams without storing local data.\nData is passed through to the destination (a non-virtual stream) after applying restrictions on the scope of files defined in the virtual stream’s view.\nBecause virtual streams do not have files in their depot namespace, it is impossible to import a virtual stream.\n\n- `release`:\nMore stable than the mainline.\nRelease streams copy from the parent and merge to the parent.\n\n- `development`:\nLess stable than the mainline.\nDevelopment streams expect to merge from parent streams and copy to the parent.\n\n- `task`:\nTask streams are lightweight short-lived branches that are useful for bug fixing or new features that only modify a small subset of the branch data.\nBecause branched (copied) files are tracked in a set of shadow tables which are later removed, repository metadata is kept to a minimum when using this type of stream.\nWorkspaces associated with task streams see all branched data, but only modified and promoted data is visible to users with access to the stream’s namespace.\nThe default is stream type is development.")
  public String getType() {
    return type;
  }
  public void setType(String type) {
    this.type = type;
  }

  
  /**
   * Description of the stream.
   **/
  @ApiModelProperty(value = "Description of the stream.")
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }

  
  /**
   * Settings that configure stream behavior as follows:\n\n- `[un]locked`:\nEnable/disable other users' ability to edit or delete the stream.\nIf locked, the stream specification cannot be deleted, and only its owner can modify it.\nThe default is unlocked.\n\n- `[all,owner]submit`:\nSpecifies whether all users or only the owner of the stream can submit changes to the stream.\nThe default is allsubmit.\nIf the Owner: of a stream marked ownersubmit is a group, all users who are members of that group can submit changes to the stream.\n\n- `[no]toparent`:\nSpecifies whether integrations from the stream to its parent are expected.\nThe default is toparent.\n\n- `[no]fromparent`:\nSpecifies whether integrations to the stream from its parent are expected.\nThe default is fromparent for mainline and development streams, and nofromparent for release streams.\n\n- `mergeany,mergedown`:\nSpecifies whether the merge flow is restricted or whether merge is permitted from any other stream.\nFor example, the mergeany option would allow a merge from a child to a parent with no warnings.\nA virtual stream must have its flow options set to notoparent and nofromparent.\nFlow options are ignored for mainline streams.
   **/
  @ApiModelProperty(value = "Settings that configure stream behavior as follows:\n\n- `[un]locked`:\nEnable/disable other users' ability to edit or delete the stream.\nIf locked, the stream specification cannot be deleted, and only its owner can modify it.\nThe default is unlocked.\n\n- `[all,owner]submit`:\nSpecifies whether all users or only the owner of the stream can submit changes to the stream.\nThe default is allsubmit.\nIf the Owner: of a stream marked ownersubmit is a group, all users who are members of that group can submit changes to the stream.\n\n- `[no]toparent`:\nSpecifies whether integrations from the stream to its parent are expected.\nThe default is toparent.\n\n- `[no]fromparent`:\nSpecifies whether integrations to the stream from its parent are expected.\nThe default is fromparent for mainline and development streams, and nofromparent for release streams.\n\n- `mergeany,mergedown`:\nSpecifies whether the merge flow is restricted or whether merge is permitted from any other stream.\nFor example, the mergeany option would allow a merge from a child to a parent with no warnings.\nA virtual stream must have its flow options set to notoparent and nofromparent.\nFlow options are ignored for mainline streams.")
  public String getOptions() {
    return options;
  }
  public void setOptions(String options) {
    this.options = options;
  }

  
  /**
   * Paths define how files are incorporated into the stream structure.\nSpecify paths using the following format:\n`path_type view_path [depot_path]`\nwhere `path_type` is a single keyword, `view_path` is a file path with no leading slashes, and the optional `depot_path` is a file path beginning with //.\n\nThe default path is `share ...`\n\nValid path types are:\n\n- `share view_path`:  Specified files can be synced, submitted, and integrated to and from the parent stream.\n\n- `isolate view_path`:  Specified files can be synced and submitted, but cannot be integrated to and from the parent stream.\n\n- `import view_path [depot_path]`: Specified files can be synced, but cannot be submitted or integrated to and from the parent stream.\nThe `view_path` is mapped as in the parent stream's view, or to an (optional) `depot_path`.\nThe `depot_path` may include a changelist specifier.\nThat stream's client workspaces will be limited to seeing revisions at that change or lower within that depot path.\nFor example, you can specify a depot path like this: `//depot/import/...@1000`.\nRevisions from changelists greater than 1000 will be automatically hidden from most commands.\nThe changelist limits in effect for a given stream workspace are displayed in a read-only client workspace specification field called ChangeView.\n\n- `import+ view_path [depot_path]`:\nFunctions like a standard import path, enabling you to map a path from outside the stream depot to your stream, but unlike a standard import path, you can submit changes to the files in an import+ path.\n\n- `exclude view_path`:\nSpecified files cannot be synced, submitted or integrated to and from the parent stream.\nBy default, streams inherit their structure from the parent stream (except mainlines, which have no parent).\nPaths are inherited by child stream views; a child stream’s path can downgrade the inherited view, but not upgrade it.\n(For example, a child stream can downgrade a shared path to an isolated path, but if the parent stream defines a path as isolated, its child cannot restore full access by specifying the path as shared.)\nNote that the `depot_path` is relevant only when the path_type is `import` or `import+`.
   **/
  @ApiModelProperty(value = "Paths define how files are incorporated into the stream structure.\nSpecify paths using the following format:\n`path_type view_path [depot_path]`\nwhere `path_type` is a single keyword, `view_path` is a file path with no leading slashes, and the optional `depot_path` is a file path beginning with //.\n\nThe default path is `share ...`\n\nValid path types are:\n\n- `share view_path`:  Specified files can be synced, submitted, and integrated to and from the parent stream.\n\n- `isolate view_path`:  Specified files can be synced and submitted, but cannot be integrated to and from the parent stream.\n\n- `import view_path [depot_path]`: Specified files can be synced, but cannot be submitted or integrated to and from the parent stream.\nThe `view_path` is mapped as in the parent stream's view, or to an (optional) `depot_path`.\nThe `depot_path` may include a changelist specifier.\nThat stream's client workspaces will be limited to seeing revisions at that change or lower within that depot path.\nFor example, you can specify a depot path like this: `//depot/import/...@1000`.\nRevisions from changelists greater than 1000 will be automatically hidden from most commands.\nThe changelist limits in effect for a given stream workspace are displayed in a read-only client workspace specification field called ChangeView.\n\n- `import+ view_path [depot_path]`:\nFunctions like a standard import path, enabling you to map a path from outside the stream depot to your stream, but unlike a standard import path, you can submit changes to the files in an import+ path.\n\n- `exclude view_path`:\nSpecified files cannot be synced, submitted or integrated to and from the parent stream.\nBy default, streams inherit their structure from the parent stream (except mainlines, which have no parent).\nPaths are inherited by child stream views; a child stream’s path can downgrade the inherited view, but not upgrade it.\n(For example, a child stream can downgrade a shared path to an isolated path, but if the parent stream defines a path as isolated, its child cannot restore full access by specifying the path as shared.)\nNote that the `depot_path` is relevant only when the path_type is `import` or `import+`.")
  public List<String> getPaths() {
    return paths;
  }
  public void setPaths(List<String> paths) {
    this.paths = paths;
  }

  
  /**
   * Reassigns the location of workspace files.\nTo specify the source path and its location in the workspace, use the following syntax:\n`view_path_1 view_path_2`\nwhere `view_path_1` and `view_path_2` are Perforce view paths (omit leading slashes and leading or embedded wildcards; terminal wildcards are fine).\nFor example, to ensure that files are synced to the local ProjectX folder, remap as follows:\n`... projectX/...`\nLine ordering in the Remapped: field is significant: if more than one line remaps the same files, the later line takes precedence.\nRemappings are inherited by child streams and the workspaces associated with them.
   **/
  @ApiModelProperty(value = "Reassigns the location of workspace files.\nTo specify the source path and its location in the workspace, use the following syntax:\n`view_path_1 view_path_2`\nwhere `view_path_1` and `view_path_2` are Perforce view paths (omit leading slashes and leading or embedded wildcards; terminal wildcards are fine).\nFor example, to ensure that files are synced to the local ProjectX folder, remap as follows:\n`... projectX/...`\nLine ordering in the Remapped: field is significant: if more than one line remaps the same files, the later line takes precedence.\nRemappings are inherited by child streams and the workspaces associated with them.")
  public List<String> getRemapped() {
    return remapped;
  }
  public void setRemapped(List<String> remapped) {
    this.remapped = remapped;
  }

  
  /**
   * A list of file or directory names to be ignored in client views. For example:\n\n```\n/tmp # ignores files named \"tmp\"\n/tmp/... # ignores directories named \"tmp\"\n.tmp # ignores file names ending in .tmp\n```\n\nLines in the `Ignored:` field can appear in any order.\nIgnored files and directories are inherited by child stream client views.
   **/
  @ApiModelProperty(value = "A list of file or directory names to be ignored in client views. For example:\n\n```\n/tmp # ignores files named \"tmp\"\n/tmp/... # ignores directories named \"tmp\"\n.tmp # ignores file names ending in .tmp\n```\n\nLines in the `Ignored:` field can appear in any order.\nIgnored files and directories are inherited by child stream client views.")
  public List<String> getIgnored() {
    return ignored;
  }
  public void setIgnored(List<String> ignored) {
    this.ignored = ignored;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    StreamCommand streamCommand = (StreamCommand) o;
    return Objects.equals(this.stream, streamCommand.stream) &&
        Objects.equals(this.update, streamCommand.update) &&
        Objects.equals(this.access, streamCommand.access) &&
        Objects.equals(this.owner, streamCommand.owner) &&
        Objects.equals(this.name, streamCommand.name) &&
        Objects.equals(this.parent, streamCommand.parent) &&
        Objects.equals(this.type, streamCommand.type) &&
        Objects.equals(this.description, streamCommand.description) &&
        Objects.equals(this.options, streamCommand.options) &&
        Objects.equals(this.paths, streamCommand.paths) &&
        Objects.equals(this.remapped, streamCommand.remapped) &&
        Objects.equals(this.ignored, streamCommand.ignored);
  }

  @Override
  public int hashCode() {
    return Objects.hash(stream, update, access, owner, name, parent, type, description, options, paths, remapped, ignored);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class StreamCommand {\n");
    
    sb.append("    stream: ").append(toIndentedString(stream)).append("\n");
    sb.append("    update: ").append(toIndentedString(update)).append("\n");
    sb.append("    access: ").append(toIndentedString(access)).append("\n");
    sb.append("    owner: ").append(toIndentedString(owner)).append("\n");
    sb.append("    name: ").append(toIndentedString(name)).append("\n");
    sb.append("    parent: ").append(toIndentedString(parent)).append("\n");
    sb.append("    type: ").append(toIndentedString(type)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("    options: ").append(toIndentedString(options)).append("\n");
    sb.append("    paths: ").append(toIndentedString(paths)).append("\n");
    sb.append("    remapped: ").append(toIndentedString(remapped)).append("\n");
    sb.append("    ignored: ").append(toIndentedString(ignored)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
