package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.*;
import java.util.Date;

import com.google.gson.annotations.SerializedName;




/**
 * Create or edit Perforce user specifications and preferences.\n\nThere are three types of Perforce users: standard users, operator users, and service users.\nStandard users are the default, and each standard user consumes one Perforce license.\nThe operator user type is intended for system administrators; they are subject to the same restrictions on permissions as any other user, but are further restricted in that they can run only a limited subset of Perforce commands.\nService users are intended for inter-server communication in replicated and multi-server environments, and are restricted to an even smaller subset of Perforce commands.\nNeither operators nor service users consume Perforce licenses.
 **/
@ApiModel(description = "Create or edit Perforce user specifications and preferences.\n\nThere are three types of Perforce users: standard users, operator users, and service users.\nStandard users are the default, and each standard user consumes one Perforce license.\nThe operator user type is intended for system administrators; they are subject to the same restrictions on permissions as any other user, but are further restricted in that they can run only a limited subset of Perforce commands.\nService users are intended for inter-server communication in replicated and multi-server environments, and are restricted to an even smaller subset of Perforce commands.\nNeither operators nor service users consume Perforce licenses.")
public class UserCommand   {
  
  @SerializedName("user")
  private String user = null;
  
  @SerializedName("type")
  private String type = null;
  
  @SerializedName("authMethod")
  private String authMethod = null;
  
  @SerializedName("email")
  private String email = null;
  
  @SerializedName("update")
  private Date update = null;
  
  @SerializedName("access")
  private Date access = null;
  
  @SerializedName("fullName")
  private String fullName = null;
  
  @SerializedName("jobView")
  private String jobView = null;
  
  @SerializedName("password")
  private String password = null;
  
  @SerializedName("passwordChange")
  private Date passwordChange = null;
  
  @SerializedName("reviews")
  private List<String> reviews = new ArrayList<String>();
  

  
  /**
   * The Perforce username.
   **/
  @ApiModelProperty(value = "The Perforce username.")
  public String getUser() {
    return user;
  }
  public void setUser(String user) {
    this.user = user;
  }

  
  /**
   * Type of user: standard, operator, or service.\n\nOnce you set the type, you cannot change it.
   **/
  @ApiModelProperty(value = "Type of user: standard, operator, or service.\n\nOnce you set the type, you cannot change it.")
  public String getType() {
    return type;
  }
  public void setType(String type) {
    this.type = type;
  }

  
  /**
   * One of the following: perforce or ldap.\n\nSpecifying perforce enables authentication using Perforce’s internal db.user table or by way of an authentication trigger.\nThis is the default unless it is overridden with the auth.default.method configurable.\n\nSpecifying ldap enables authentication against AD/LDAP servers specified by the currently active LDAP configurations.
   **/
  @ApiModelProperty(value = "One of the following: perforce or ldap.\n\nSpecifying perforce enables authentication using Perforce’s internal db.user table or by way of an authentication trigger.\nThis is the default unless it is overridden with the auth.default.method configurable.\n\nSpecifying ldap enables authentication against AD/LDAP servers specified by the currently active LDAP configurations.")
  public String getAuthMethod() {
    return authMethod;
  }
  public void setAuthMethod(String authMethod) {
    this.authMethod = authMethod;
  }

  
  /**
   * The user’s email address. By default, this is user@client.
   **/
  @ApiModelProperty(value = "The user’s email address. By default, this is user@client.")
  public String getEmail() {
    return email;
  }
  public void setEmail(String email) {
    this.email = email;
  }

  
  /**
   * The date and time this specification was last updated.
   **/
  @ApiModelProperty(value = "The date and time this specification was last updated.")
  public Date getUpdate() {
    return update;
  }
  public void setUpdate(Date update) {
    this.update = update;
  }

  
  /**
   * The date and time this user last ran a Perforce command.
   **/
  @ApiModelProperty(value = "The date and time this user last ran a Perforce command.")
  public Date getAccess() {
    return access;
  }
  public void setAccess(Date access) {
    this.access = access;
  }

  
  /**
   * The user's full name.
   **/
  @ApiModelProperty(value = "The user's full name.")
  public String getFullName() {
    return fullName;
  }
  public void setFullName(String fullName) {
    this.fullName = fullName;
  }

  
  /**
   * Jobs matching this jobview appear on any changelists created by this user.\nJobs that are fixed by the changelist should be left in the changelist when it's submitted with p4 submit; other jobs should be deleted from the form before submission.
   **/
  @ApiModelProperty(value = "Jobs matching this jobview appear on any changelists created by this user.\nJobs that are fixed by the changelist should be left in the changelist when it's submitted with p4 submit; other jobs should be deleted from the form before submission.")
  public String getJobView() {
    return jobView;
  }
  public void setJobView(String jobView) {
    this.jobView = jobView;
  }

  
  /**
   * The user's password.
   **/
  @ApiModelProperty(value = "The user's password.")
  public String getPassword() {
    return password;
  }
  public void setPassword(String password) {
    this.password = password;
  }

  
  /**
   * The date and time of the user’s last password change.\nIf the user has no password, this field is blank.
   **/
  @ApiModelProperty(value = "The date and time of the user’s last password change.\nIf the user has no password, this field is blank.")
  public Date getPasswordChange() {
    return passwordChange;
  }
  public void setPasswordChange(Date passwordChange) {
    this.passwordChange = passwordChange;
  }

  
  /**
   * A list of files the user would like to review.\nThis field can include exclusionary mappings.
   **/
  @ApiModelProperty(value = "A list of files the user would like to review.\nThis field can include exclusionary mappings.")
  public List<String> getReviews() {
    return reviews;
  }
  public void setReviews(List<String> reviews) {
    this.reviews = reviews;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    UserCommand userCommand = (UserCommand) o;
    return Objects.equals(this.user, userCommand.user) &&
        Objects.equals(this.type, userCommand.type) &&
        Objects.equals(this.authMethod, userCommand.authMethod) &&
        Objects.equals(this.email, userCommand.email) &&
        Objects.equals(this.update, userCommand.update) &&
        Objects.equals(this.access, userCommand.access) &&
        Objects.equals(this.fullName, userCommand.fullName) &&
        Objects.equals(this.jobView, userCommand.jobView) &&
        Objects.equals(this.password, userCommand.password) &&
        Objects.equals(this.passwordChange, userCommand.passwordChange) &&
        Objects.equals(this.reviews, userCommand.reviews);
  }

  @Override
  public int hashCode() {
    return Objects.hash(user, type, authMethod, email, update, access, fullName, jobView, password, passwordChange, reviews);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class UserCommand {\n");
    
    sb.append("    user: ").append(toIndentedString(user)).append("\n");
    sb.append("    type: ").append(toIndentedString(type)).append("\n");
    sb.append("    authMethod: ").append(toIndentedString(authMethod)).append("\n");
    sb.append("    email: ").append(toIndentedString(email)).append("\n");
    sb.append("    update: ").append(toIndentedString(update)).append("\n");
    sb.append("    access: ").append(toIndentedString(access)).append("\n");
    sb.append("    fullName: ").append(toIndentedString(fullName)).append("\n");
    sb.append("    jobView: ").append(toIndentedString(jobView)).append("\n");
    sb.append("    password: ").append(toIndentedString(password)).append("\n");
    sb.append("    passwordChange: ").append(toIndentedString(passwordChange)).append("\n");
    sb.append("    reviews: ").append(toIndentedString(reviews)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
